﻿// Disclaimer:
// This software is provided AS IS for educational purposes only,
// with no warranties, and confers no rights. Error checking is 
// elided for clarity. Carry out sufficient tests prior to using
// it in a productive environment.
// CASIO Europe GmbH accepts no responsibility for loss or damage
// arising from its use, including damage from virus.
//
// Please, note: This configuration information may be changed
// without any further notice.
// Casio Europe GmbH does not guarantee future compatibility. By 
// using this software you agree to these terms and conditions.
//
// Version 0.01 - December 19, 2011
// Supported Devices: IT-800 (Windows Mobile Professional)
//
// Remarks: You need latest versions of patches and runtime
// libraries be installed onto your mobile device.
//////////////////////////////////////////////////////////////////////

using System;
using System.ComponentModel;
using System.Windows.Forms;
using System.Reflection;
using Microsoft.WindowsMobile.PocketOutlook.MessageInterception;
using Microsoft.WindowsMobile.Status;
using Calib;

namespace RemoteWipe
{
    public partial class MainForm : Form
    {
        #region Fields
        private MessageInterceptor smsInterceptor;
        private string smsCommand;
        #endregion

        #region Constants
        // You need the admins's password to enable/disable Remote Wipe.
        private const string AdminPassword = "123456";
        private const int ModelSupported = 13;
        private const string ApplicationLaunchId = "RemoteWipe";
        private const string SmsCommandPrefix = "Wipe";
        #endregion

        public MainForm()
        {
            InitializeComponent();

            this.lblInfo.Text = Resources.CommonInfo;
            this.menuEnable.Text = Resources.MenuEnableText;
            this.menuDisable.Text = Resources.MenuDisableText;

            // Send this command to the device via SMS in order to execute Remote Wipe.
            // The command consists of the prefix "Wipe" and the serial number (5 digits).
            this.smsCommand = GetSmsCommand();
            bool supported = GetPlatformSupported();
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            // Retrieve current status.
            if (MessageInterceptor.IsApplicationLauncherEnabled(ApplicationLaunchId) == true)
            {
                this.smsInterceptor = new MessageInterceptor(ApplicationLaunchId);
                this.smsInterceptor.MessageReceived +=
                    new MessageInterceptorEventHandler(smsInterceptor_MessageReceived);
                ShowStatus(true);
            }
            else
            {
                ShowStatus(false);
            }
        }

        private void MainForm_Closing(object sender, CancelEventArgs e)
        {
            if (MessageInterceptor.IsApplicationLauncherEnabled(ApplicationLaunchId) == true &&
                this.smsInterceptor != null)
            {
                this.smsInterceptor.MessageReceived -= smsInterceptor_MessageReceived;
            }
        }

        private void menuEnable_Click(object sender, EventArgs e)
        {
            if (MessageInterceptor.IsApplicationLauncherEnabled(ApplicationLaunchId) == false)
            {
                PasswordForm pwdForm = new PasswordForm();

                if (pwdForm.ShowDialog() == DialogResult.OK &&
                    pwdForm.AdminPassword == AdminPassword)
                {
                    // Define filter for incoming SMS.
                    this.smsInterceptor = new MessageInterceptor(InterceptionAction.NotifyAndDelete);
                    this.smsInterceptor.MessageCondition = new MessageCondition(
                        MessageProperty.Body,
                        MessagePropertyComparisonType.Equal,
                        this.smsCommand);
                    string appPath = Assembly.GetExecutingAssembly().GetName().CodeBase;
                    this.smsInterceptor.EnableApplicationLauncher(ApplicationLaunchId, appPath);
                    this.smsInterceptor.MessageReceived +=
                        new MessageInterceptorEventHandler(smsInterceptor_MessageReceived);
                    ShowStatus(true);
                    this.lblSmsCommand.Text = 
                        string.Format("{0} {1}", Resources.SmsCommandInfo, this.smsCommand);
                }
            }
        }

        void smsInterceptor_MessageReceived(object sender, MessageInterceptorEventArgs e)
        {
            NativeMethods.UserDiskClear();
        }
        
        private void menuDisable_Click(object sender, EventArgs e)
        {
            if (MessageInterceptor.IsApplicationLauncherEnabled(ApplicationLaunchId) == true)
            {
                PasswordForm pwdForm = new PasswordForm();

                if (pwdForm.ShowDialog() == DialogResult.OK &&
                    pwdForm.AdminPassword == AdminPassword &&
                    this.smsInterceptor != null)
                {
                    this.smsInterceptor.MessageReceived -= smsInterceptor_MessageReceived;
                    this.smsInterceptor.DisableApplicationLauncher();
                    ShowStatus(false);
                    this.lblSmsCommand.Text = "";
                }
            }
        }

        private void ShowStatus(bool enabled)
        {
            if (enabled == true)
            {
                this.lblStatus.Text = Resources.StatusEnabledText;
            }
            else
            {
                this.lblStatus.Text = Resources.StatusDisabledText;
            }
        }

        private static string GetSmsCommand()
        {
            // Send this command to the device via SMS in order to execute Remote Wipe.
            // The command consists of the prefix "Wipe" and the serial number (5 digits).
            string result = SmsCommandPrefix;
            char[] buffer = new char[32];

            if (SystemLibNet.Api.SysGetDeviceIDCode(buffer) == -1)
            {
                result += new string(buffer, 4, 5);
            }

            return result;
        }

        private static bool GetPlatformSupported()
        {
            bool supported = false;
            int model = 0;
            int version = 0;
            int platform = 0;

            if (SystemLibNet.Api.SysGetModelName(ref model, ref version, ref platform) == -1 &&
                model == ModelSupported &&
                SystemState.PhoneRadioPresent == true)
            {
                supported = true;
            }

            return supported;
        }
    }
}